CmdUtils.CreateCommand({
  name: "amazon-jp-search",
  icon: "http://www.amazon.co.jp/favicon.ico",
  author: { name: "Taro Matsuzawa", email: "btm@mozilla.gr.jp"},
  license: "GPL",
  description: "Searches <a href=\"http://www.amazon.co.jp\">Amazon.co.jp</a> for books matching your words.",
  url: "http://www.amazon.co.jp/s/ref=nb_ss_gw?__mk_ja_JP=%83J%83%5E%83J%83i&url=search-alias%3Dstripbooks&field-keywords={QUERY}&x=0&y=0",
  takes: {"input": noun_arb_text},
  preview: function( pblock, input ) {
    if(!input.text || input.text.length < 1) {
      pblock.innerHTML = "Searches for books on Amazon.co.jp";
      return;
    }

    pblock.innerHTML = "Searching Amazon for books matching <b>" + input.summary + "</b>";
    
    var apiUrl = "http://webservices.amazon.co.jp/onca/xml";
    var apiParams = {
      Service: "AWSECommerceService",
      AWSAccessKeyId: "subscription ID",
      AssociateTag: "A\VGCgID",
      Version: "2008-04-07",
      Operation: "ItemSearch",
      Condition: "All",
      ResponseGroup: "ItemAttributes,Images",
      SearchIndex: "Books",
      Title: input.text
    };
    CmdUtils.previewAjax(pblock, {
      type: "GET",
      url: apiUrl,
      data: apiParams,
      dataType: "xml",
      error: function() {
        previewBlock.innerHTML = "Error searching Amazon.";
      },
      success: function(responseData) {
        const AMAZON_MAX_RESULTS = 5;
	//(1)
        responseData = jQuery(responseData);
	//(2)
        var items = [];
        
	//(3)
        responseData.find("Items Item").slice(0, AMAZON_MAX_RESULTS).each(function(itemIndex) {
	  //(4)
          var itemDetails = jQuery(this);
          //(5)
          var newItem = {
            title: itemDetails.find("ItemAttributes Title").text(),
            url: itemDetails.find("DetailPageURL").text()
          };
          //(6)
          if(itemDetails.find("ItemAttributes Author").length > 0) {
            newItem.author = itemDetails.find("ItemAttributes Author").text();
          }
	  //(7)
          if(itemDetails.find("ItemAttributes ListPrice").length > 0) {
            newItem.price = {
              amount: itemDetails.find("ItemAttributes ListPrice FormattedPrice").text(),
              currency: itemDetails.find("ItemAttributes ListPrice CurrencyCode").text()
            };
          }
	  //(8)
          items.push(newItem);
        });
	//(9)
        var previewData = {
          query: input.summary,
          numitems: responseData.find("Items TotalResults").text(),
          items: items
        };
	//(10)
        var templateHtml = '<div id="amazon-jp-search">' +
            'Found ${numitems} books on Amazon matching <b>${query}</b>' +
            '{for item in items}' +
            '<div>' +
            '<a href="${item.url}">' +
            '<u>${item.title}</u>' +
            '</a>' +
            '<small>' +
            '{if item.author}' +
            ' by ${item.author}' +
            '{/if}' +
            '{if item.price}' +
            ' for ${item.price.amount} (${item.price.currency})' +
            '{/if}' +
            '</small>' +
            '</div>' +
            '{/for}' +
            '</div>';

	//(11)
        pblock.innerHTML = CmdUtils.renderTemplate(templateHtml,previewData);
	//(12)
	//CmdUtils.log(CmdUtils.renderTemplate(templateHtml,previewData));      
      },
    });
  },
  execute: function(input) {    
    var query = escape(this.convertUTF16toSJIS(input.text));
    var urlString = this.url.replace("{QUERY}", query);
    Utils.openUrlInBrowser(urlString);
    CmdUtils.setLastResult(urlString);
  },
  convertUTF16toSJIS: function(u_str) {
    var UConvID = '@mozilla.org/intl/scriptableunicodeconverter';
    var UConvIF  = Components.interfaces.nsIScriptableUnicodeConverter;
    var UConv = Components.classes[UConvID].getService(UConvIF);
    UConv.charset = 'SHIFT-JIS';
    return UConv.ConvertFromUnicode(u_str);
  }
});
